@@ -7,8 +7,8 @@ import ExceptionHandling
 
 class TestExceptionHandling (TestCase):
     def testClasses(self):
-        self.assert_(hasattr(ExceptionHandling, 'NSExceptionHandler'))
-        self.assert_(isinstance(ExceptionHandling.NSExceptionHandler, objc.objc_class))
+        self.assertHasAttr(ExceptionHandling, 'NSExceptionHandler')
+        self.assertIsInstance(ExceptionHandling.NSExceptionHandler, objc.objc_class)
 
 if __name__ == "__main__":
     main()
